# Generated by roxygen2: do not edit by hand

export(describe_table)
export(get_company)
export(get_compustat)
export(get_table)
export(link_ccm)
export(link_ibes_crsp)
export(list_subscriptions)
export(list_tables)
export(sic_2digit)
export(wrds_connect)
export(wrds_disconnect)
export(wrds_set_credentials)
export(wrds_update_password)
importFrom(dbplyr,in_schema)
importFrom(dplyr,tbl)
importFrom(rlang,.env)
