% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/list.R
\name{list_tables}
\alias{list_tables}
\title{List tables in a library}
\usage{
list_tables(wrds, library)
}
\arguments{
\item{wrds}{A \code{DBIConnection} object returned by \code{\link[=wrds_connect]{wrds_connect()}}.}

\item{library}{Character. The name of the library (schema) to query.}
}
\value{
A character vector of table names.
}
\description{
Returns a character vector of table names within a WRDS library (schema).
}
\examples{
\dontrun{
wrds <- wrds_connect()
list_tables(wrds, "comp")
wrds_disconnect(wrds)
}
}
