% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get-compustat.R
\name{fill_sic_codes}
\alias{fill_sic_codes}
\title{Fill missing SIC codes from company header}
\usage{
fill_sic_codes(tbl, wrds)
}
\arguments{
\item{tbl}{A lazy table from funda/fundq.}

\item{wrds}{Database connection.}
}
\value{
A collected tibble with \code{sic} column (character, coalesced from
\code{sich} and header \code{sic}).
}
\description{
Internal function that joins fundamentals data with company header
to fill missing historical SIC codes using coalesce.
}
\keyword{internal}
