% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wrds-connect.R
\name{wrds_update_password}
\alias{wrds_update_password}
\title{Update WRDS password}
\usage{
wrds_update_password(password_key = "wrds_pw", keyring = NULL)
}
\arguments{
\item{password_key}{Name for the password keyring entry. Defaults to \code{"wrds_pw"}.}

\item{keyring}{Optional keyring name. If \code{NULL} (default), uses the
default keyring.}
}
\value{
Invisibly returns \code{TRUE} on success.
}
\description{
Interactively updates the WRDS password stored in the system keyring
without changing the username.
}
\examples{
\dontrun{
wrds_update_password()
}
}
\seealso{
\code{\link[=wrds_set_credentials]{wrds_set_credentials()}}, \code{\link[=wrds_connect]{wrds_connect()}}
}
